# Webform Booking Module

The Webform Booking module seamlessly integrates a simple booking system into any webform.

## Table of Contents

1. Features
2. Requirements
3. Installation
4. Configuration
5. PayPal Integration
6. Troubleshooting
7. Similar Projects
8. Maintainers

## Features

1. **Flexible Booking Slots:** Easily define time intervals and duration for each booking slot, allowing custom
   schedules and appointments.
2. **Weekday Management:** Disable bookings on specific weekdays (e.g., Saturdays and Sundays) and set different time
   periods for specific days of the week.
3. **Date and Time Exclusions:** Exclude specific dates or time periods for booking, accommodating holidays, events, or
   personal time off.
4. **Real-Time Availability Checks:** Automatically check for booked slots, preventing double bookings for a smooth and
   efficient user experience.
5. **Customizable for Any Webform:** Versatile design to be added to any webform within your Drupal site, providing a
   tailored booking solution.
6. **PayPal Integration:** Optional PayPal integration for seamless payment processing.

## Requirements

- Webform

## Installation

Install as you would normally install a contributed Drupal module. For further
information, see [Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).

## Configuration

1. Once the module is activated, navigate to the configuration page.
2. Add a 'Webform Booking' element to your desired webform.
3. Pay close attention to the provided formats and examples within the tooltips to ensure optimal setup and
   functionality.

## PayPal Integration

The Webform Booking module supports PayPal integration for processing payments. To enable and configure PayPal:

1. In the Webform Booking element settings, check the "Enable PayPal integration" box.
2. Enter your PayPal Client ID.
3. Choose between Sandbox (for testing) or Live environment.
4. Set the default price per seat and select the currency.

### Obtaining PayPal API Credentials

To use PayPal integration, you need to obtain API credentials from PayPal. Follow these steps:

1. Go to the [PayPal Developer Dashboard](https://developer.paypal.com/dashboard/).
2. Log in or create a PayPal account if you don't have one.
3. Click on "Apps & Credentials" in the left menu.
4. Click "Create App" to create a new application.
5. Choose a name for your app and select "Merchant" as the app type.
6. Once created, you'll see the Client ID and Secret. Use the Client ID in your Webform Booking settings.
7. For testing, use the Sandbox environment. For real transactions, switch to the Live environment and create a live app to get production credentials.

Remember to keep your API credentials secure and never share them publicly.

## Troubleshooting

If you encounter any issues with the Webform Booking module, consider the following steps:

- Ensure that all module dependencies are met.
- Check for conflicts with other modules.
- Review the Drupal logs for any error messages.
- For PayPal-related issues, verify your API credentials and ensure you're using the correct environment (Sandbox or Live).

## Similar Projects

- The BEE and BAT (Booking and Availability Management Tools) may offer similar functionality with increased complexity
  and dependencies.

## Maintainers

- Ricardo Marcelino [rfmarcelino](https://www.drupal.org/u/rfmarcelino)

#### Supporting organizations:

- Initial development [Universidade do Minho](https://www.drupal.org/universidade-do-minho)
- Ongoing support [Omibee](https://www.drupal.org/omibee)
