<?php

namespace Drupal\webform_booking\Element;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Element;
use Drupal\Core\Render\Element\FormElement;

/**
 * Provides a custom form element for booking.
 *
 * @FormElement("webform_booking")
 */
class WebformBooking extends FormElement {

  /**
   * {@inheritdoc}
   */
  public function getInfo() {
    $class = get_class($this);
    return [
      '#input' => TRUE,
      '#size' => 60,
      '#process' => [
        [$class, 'processWebformBooking'],
        [$class, 'processAjaxForm'],
      ],
      '#element_validate' => [
        [$class, 'validateWebformBooking'],
      ],
      '#pre_render' => [
        [$class, 'preRenderWebformBookingElement'],
      ],
      '#theme' => 'input__webform_booking',
      '#theme_wrappers' => ['form_element'],
    ];
  }

  /**
   * Process webform booking element.
   */
  public static function processWebformBooking(&$element, FormStateInterface $form_state, &$complete_form) {
    return $element;
  }

  /**
   * Pre-render callback for the webform booking element.
   */
  public static function preRenderWebformBookingElement($element) {
    $element['#attributes']['type'] = 'text';
    $element['#attributes']['id'] = 'selected-slot-' . $element["#webform_key"];
    Element::setAttributes($element, ['id', 'name', 'value', 'size', 'maxlength', 'placeholder']);
    static::setAttributes($element, ['form-text', 'form-element--webform-booking']);
    return $element;
  }

  /**
   * Validation for the element.
   */
  public static function validateWebformBooking(&$element, FormStateInterface $form_state, &$complete_form) {
    $value = $element['#value'];
    $dateTime = \DateTime::createFromFormat('Y-m-d H:i', $value);
    if ($dateTime === FALSE || $dateTime->format('Y-m-d H:i') !== $value) {
      $form_state->setError($element, t('The provided value must be in the format YYYY-MM-DD HH:MM, for example, 2024-03-12 14:30.'));
    }
  }

}
