<?php

namespace Drupal\webform_booking\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Webform booking settings form.
 */
class WebformBookingSettingsForm extends ConfigFormBase {

  /**
   * Get editable config names.
   */
  protected function getEditableConfigNames() {
    return ['webform_booking.settings'];
  }

  /**
   * Get form id.
   */
  public function getFormId() {
    return 'webform_booking_settings_form';
  }

  /**
   * Build form.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('webform_booking.settings');

    $form['paypal_client_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('PayPal Client ID'),
      '#default_value' => $config->get('paypal_client_id'),
    ];

    $form['paypal_environment'] = [
      '#type' => 'select',
      '#title' => $this->t('PayPal Environment'),
      '#options' => [
        'sandbox' => $this->t('Sandbox (Testing)'),
        'live' => $this->t('Live (Production)'),
      ],
      '#default_value' => $config->get('paypal_environment'),
    ];

    $form['currency'] = [
      '#type' => 'select',
      '#title' => $this->t('Currency'),
      '#options' => [
        'AUD' => $this->t('Australian dollar (AUD)'),
        'BRL' => $this->t('Brazilian real (BRL)'),
        'CAD' => $this->t('Canadian dollar (CAD)'),
        'CNY' => $this->t('Chinese Renminbi (CNY)'),
        'CZK' => $this->t('Czech koruna (CZK)'),
        'DKK' => $this->t('Danish krone (DKK)'),
        'EUR' => $this->t('Euro (EUR)'),
        'HKD' => $this->t('Hong Kong dollar (HKD)'),
        'HUF' => $this->t('Hungarian forint (HUF)'),
        'ILS' => $this->t('Israeli new shekel (ILS)'),
        'JPY' => $this->t('Japanese yen (JPY)'),
        'MYR' => $this->t('Malaysian ringgit (MYR)'),
        'MXN' => $this->t('Mexican peso (MXN)'),
        'TWD' => $this->t('New Taiwan dollar (TWD)'),
        'NZD' => $this->t('New Zealand dollar (NZD)'),
        'NOK' => $this->t('Norwegian krone (NOK)'),
        'PHP' => $this->t('Philippine peso (PHP)'),
        'PLN' => $this->t('Polish złoty (PLN)'),
        'GBP' => $this->t('Pound sterling (GBP)'),
        'SGD' => $this->t('Singapore dollar (SGD)'),
        'SEK' => $this->t('Swedish krona (SEK)'),
        'CHF' => $this->t('Swiss franc (CHF)'),
        'THB' => $this->t('Thai baht (THB)'),
        'USD' => $this->t('United States dollar (USD)'),
      ],
      '#default_value' => $config->get('currency') ?? 'USD',
      '#description' => $this->t('Select the currency for PayPal transactions.'),
    ];

    $form['paypal_default_country'] = [
      '#type' => 'select',
      '#title' => $this->t('PayPal Default Country'),
      '#options' => [
        'AL' => $this->t('Albania (en_US)'),
        'DZ' => $this->t('Algeria (ar_EG)'),
        'AD' => $this->t('Andorra (en_US)'),
        'AO' => $this->t('Angola (en_US)'),
        'AI' => $this->t('Anguilla (en_US)'),
        'AG' => $this->t('Antigua & Barbuda (en_US)'),
        'AR' => $this->t('Argentina (es_XC)'),
        'AM' => $this->t('Armenia (en_US)'),
        'AW' => $this->t('Aruba (en_US)'),
        'AU' => $this->t('Australia (en_AU)'),
        'AT' => $this->t('Austria (de_DE)'),
        'AZ' => $this->t('Azerbaijan (en_US)'),
        'BS' => $this->t('Bahamas (en_US)'),
        'BH' => $this->t('Bahrain (ar_EG)'),
        'BB' => $this->t('Barbados (en_US)'),
        'BY' => $this->t('Belarus (en_US)'),
        'BE' => $this->t('Belgium (en_US)'),
        'BZ' => $this->t('Belize (es_XC)'),
        'BJ' => $this->t('Benin (fr_XC)'),
        'BM' => $this->t('Bermuda (en_US)'),
        'BT' => $this->t('Bhutan (en_US)'),
        'BO' => $this->t('Bolivia (es_XC)'),
        'BA' => $this->t('Bosnia & Herzegovina (en_US)'),
        'BW' => $this->t('Botswana (en_US)'),
        'BR' => $this->t('Brazil (pt_BR)'),
        'VG' => $this->t('British Virgin Islands (en_US)'),
        'BN' => $this->t('Brunei (en_US)'),
        'BG' => $this->t('Bulgaria (en_US)'),
        'BF' => $this->t('Burkina Faso (fr_XC)'),
        'BI' => $this->t('Burundi (fr_XC)'),
        'KH' => $this->t('Cambodia (en_US)'),
        'CM' => $this->t('Cameroon (fr_XC)'),
        'CA' => $this->t('Canada (en_US)'),
        'CV' => $this->t('Cape Verde (en_US)'),
        'KY' => $this->t('Cayman Islands (en_US)'),
        'TD' => $this->t('Chad (fr_XC)'),
        'CL' => $this->t('Chile (es_XC)'),
        'CN' => $this->t('China (zh_CN)'),
        'XC' => $this->t('China Worldwide (zh_XC)'),
        'CO' => $this->t('Colombia (es_XC)'),
        'KM' => $this->t('Comoros (fr_XC)'),
        'CG' => $this->t('Congo - Brazzaville (en_US)'),
        'CD' => $this->t('Congo - Kinshasa (fr_XC)'),
        'CK' => $this->t('Cook Islands (en_US)'),
        'CR' => $this->t('Costa Rica (es_XC)'),
        'CI' => $this->t('Côte d’Ivoire (fr_XC)'),
        'HR' => $this->t('Croatia (en_US)'),
        'CY' => $this->t('Cyprus (en_US)'),
        'CZ' => $this->t('Czech Republic (cs_CZ)'),
        'DK' => $this->t('Denmark (da_DK)'),
        'DJ' => $this->t('Djibouti (fr_XC)'),
        'DM' => $this->t('Dominica (en_US)'),
        'DO' => $this->t('Dominican Republic (es_XC)'),
        'EC' => $this->t('Ecuador (es_XC)'),
        'EG' => $this->t('Egypt (ar_EG)'),
        'SV' => $this->t('El Salvador (es_XC)'),
        'ER' => $this->t('Eritrea (en_US)'),
        'EE' => $this->t('Estonia (en_US)'),
        'ET' => $this->t('Ethiopia (en_US)'),
        'FK' => $this->t('Falkland Islands (en_US)'),
        'FO' => $this->t('Faroe Islands (da_DK)'),
        'FJ' => $this->t('Fiji (en_US)'),
        'FI' => $this->t('Finland (fi_FI)'),
        'FR' => $this->t('France (fr_FR)'),
        'GF' => $this->t('French Guiana (en_US)'),
        'PF' => $this->t('French Polynesia (en_US)'),
        'GA' => $this->t('Gabon (fr_XC)'),
        'GM' => $this->t('Gambia (en_US)'),
        'GE' => $this->t('Georgia (en_US)'),
        'DE' => $this->t('Germany (de_DE)'),
        'GI' => $this->t('Gibraltar (en_US)'),
        'GR' => $this->t('Greece (el_GR)'),
        'GL' => $this->t('Greenland (da_DK)'),
        'GD' => $this->t('Grenada (en_US)'),
        'GP' => $this->t('Guadeloupe (en_US)'),
        'GT' => $this->t('Guatemala (es_XC)'),
        'GN' => $this->t('Guinea (fr_XC)'),
        'GW' => $this->t('Guinea-Bissau (en_US)'),
        'GY' => $this->t('Guyana (en_US)'),
        'HN' => $this->t('Honduras (es_XC)'),
        'HK' => $this->t('Hong Kong SAR China (en_GB)'),
        'HU' => $this->t('Hungary (hu_HU)'),
        'IS' => $this->t('Iceland (en_US)'),
        'IN' => $this->t('India (en_IN)'),
        'ID' => $this->t('Indonesia (id_ID)'),
        'IE' => $this->t('Ireland (en_US)'),
        'IL' => $this->t('Israel (he_IL)'),
        'IT' => $this->t('Italy (it_IT)'),
        'JM' => $this->t('Jamaica (es_XC)'),
        'JP' => $this->t('Japan (ja_JP)'),
        'JO' => $this->t('Jordan (ar_EG)'),
        'KZ' => $this->t('Kazakhstan (en_US)'),
        'KE' => $this->t('Kenya (en_US)'),
        'KI' => $this->t('Kiribati (en_US)'),
        'KW' => $this->t('Kuwait (ar_EG)'),
        'KG' => $this->t('Kyrgyzstan (en_US)'),
        'LA' => $this->t('Laos (en_US)'),
        'LV' => $this->t('Latvia (en_US)'),
        'LS' => $this->t('Lesotho (en_US)'),
        'LI' => $this->t('Liechtenstein (en_US)'),
        'LT' => $this->t('Lithuania (en_US)'),
        'LU' => $this->t('Luxembourg (en_US)'),
        'MK' => $this->t('Macedonia (en_US)'),
        'MG' => $this->t('Madagascar (en_US)'),
        'MW' => $this->t('Malawi (en_US)'),
        'MY' => $this->t('Malaysia (en_US)'),
        'MV' => $this->t('Maldives (en_US)'),
        'ML' => $this->t('Mali (fr_XC)'),
        'MT' => $this->t('Malta (en_US)'),
        'MH' => $this->t('Marshall Islands (en_US)'),
        'MQ' => $this->t('Martinique (en_US)'),
        'MR' => $this->t('Mauritania (en_XC)'),
        'MU' => $this->t('Mauritius (en_US)'),
        'YT' => $this->t('Mayotte (en_US)'),
        'MX' => $this->t('Mexico (es_XC)'),
        'FM' => $this->t('Micronesia (en_US)'),
        'MD' => $this->t('Moldova (en_US)'),
        'MC' => $this->t('Monaco (fr_XC)'),
        'MN' => $this->t('Mongolia (en_US)'),
        'ME' => $this->t('Montenegro (en_US)'),
        'MS' => $this->t('Montserrat (en_US)'),
        'MA' => $this->t('Morocco (ar_EG)'),
        'MZ' => $this->t('Mozambique (en_US)'),
        'NA' => $this->t('Namibia (en_US)'),
        'NR' => $this->t('Nauru (en_US)'),
        'NP' => $this->t('Nepal (en_US)'),
        'NL' => $this->t('Netherlands (nl_NL)'),
        'NC' => $this->t('New Caledonia (en_US)'),
        'NZ' => $this->t('New Zealand (en_US)'),
        'NI' => $this->t('Nicaragua (es_XC)'),
        'NE' => $this->t('Niger (fr_XC)'),
        'NG' => $this->t('Nigeria (en_US)'),
        'NU' => $this->t('Niue (en_US)'),
        'NF' => $this->t('Norfolk Island (en_US)'),
        'NO' => $this->t('Norway (no_NO)'),
        'OM' => $this->t('Oman (ar_EG)'),
        'PW' => $this->t('Palau (en_US)'),
        'PA' => $this->t('Panama (es_XC)'),
        'PG' => $this->t('Papua New Guinea (en_US)'),
        'PY' => $this->t('Paraguay (es_XC)'),
        'PE' => $this->t('Peru (es_XC)'),
        'PH' => $this->t('Philippines (en_US)'),
        'PN' => $this->t('Pitcairn Islands (en_US)'),
        'PL' => $this->t('Poland (pl_PL)'),
        'PT' => $this->t('Portugal (pt_PT)'),
        'QA' => $this->t('Qatar (en_US)'),
        'RE' => $this->t('Réunion (en_US)'),
        'RO' => $this->t('Romania (en_US)'),
        'RU' => $this->t('Russia (ru_RU)'),
        'RW' => $this->t('Rwanda (fr_XC)'),
        'WS' => $this->t('Samoa (en_US)'),
        'SM' => $this->t('San Marino (en_US)'),
        'ST' => $this->t('São Tomé & Príncipe (en_US)'),
        'SA' => $this->t('Saudi Arabia (ar_EG)'),
        'SN' => $this->t('Senegal (fr_XC)'),
        'RS' => $this->t('Serbia (en_US)'),
        'SC' => $this->t('Seychelles (fr_XC)'),
        'SL' => $this->t('Sierra Leone (en_US)'),
        'SG' => $this->t('Singapore (en_GB)'),
        'SK' => $this->t('Slovakia (sk_SK)'),
        'SI' => $this->t('Slovenia (en_US)'),
        'SB' => $this->t('Solomon Islands (en_US)'),
        'SO' => $this->t('Somalia (en_US)'),
        'ZA' => $this->t('South Africa (en_US)'),
        'KR' => $this->t('South Korea (ko_KR)'),
        'ES' => $this->t('Spain (es_ES)'),
        'LK' => $this->t('Sri Lanka (en_US)'),
        'SH' => $this->t('St. Helena (en_US)'),
        'KN' => $this->t('St. Kitts & Nevis (en_US)'),
        'LC' => $this->t('St. Lucia (en_US)'),
        'PM' => $this->t('St. Pierre & Miquelon (en_US)'),
        'VC' => $this->t('St. Vincent & Grenadines (en_US)'),
        'SR' => $this->t('Suriname (en_US)'),
        'SJ' => $this->t('Svalbard & Jan Mayen (en_US)'),
        'SZ' => $this->t('Swaziland (en_US)'),
        'SE' => $this->t('Sweden (sv_SE)'),
        'CH' => $this->t('Switzerland (de_DE)'),
        'TW' => $this->t('Taiwan (zh_TW)'),
        'TJ' => $this->t('Tajikistan (en_US)'),
        'TZ' => $this->t('Tanzania (en_US)'),
        'TH' => $this->t('Thailand (th_TH)'),
        'TG' => $this->t('Togo (fr_XC)'),
        'TO' => $this->t('Tonga (en_US)'),
        'TT' => $this->t('Trinidad & Tobago (en_US)'),
        'TN' => $this->t('Tunisia (ar_EG)'),
        'TM' => $this->t('Turkmenistan (en_US)'),
        'TC' => $this->t('Turks & Caicos Islands (en_US)'),
        'TV' => $this->t('Tuvalu (en_US)'),
        'UG' => $this->t('Uganda (en_US)'),
        'UA' => $this->t('Ukraine (en_US)'),
        'AE' => $this->t('United Arab Emirates (en_US)'),
        'GB' => $this->t('United Kingdom (en_GB)'),
        'US' => $this->t('United States (en_US)'),
        'UY' => $this->t('Uruguay (es_XC)'),
        'VU' => $this->t('Vanuatu (en_US)'),
        'VA' => $this->t('Vatican City (en_US)'),
        'VE' => $this->t('Venezuela (es_XC)'),
        'VN' => $this->t('Vietnam (en_US)'),
        'WF' => $this->t('Wallis & Futuna (en_US)'),
        'YE' => $this->t('Yemen (ar_EG)'),
        'ZM' => $this->t('Zambia (en_US)'),
        'ZW' => $this->t('Zimbabwe (en_US)'),
      ],
      '#default_value' => $config->get('paypal_default_country') ?? 'en_GB',
      '#description' => $this->t('Select the default country for PayPal transactions.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * Submit form.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('webform_booking.settings')
      ->set('paypal_client_id', $form_state->getValue('paypal_client_id'))
      ->set('paypal_environment', $form_state->getValue('paypal_environment'))
      ->set('currency', $form_state->getValue('currency'))
      ->set('paypal_default_country', $form_state->getValue('paypal_default_country'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
